import json
import requests

def get_topanime(years = 2020):
    try:
        if int(years) > 1:
            get_topanimes = requests.get('https://dbuapi.herokuapp.com/aimedbu?method=get_topanime&year={}'.format(years)).json()

        return json.loads(get_topanimes)
    except:
        return 'DBU_EROR: Год должен быть числом.'

def get_anime():
    
    get_animes = requests.get('https://dbuapi.herokuapp.com/aimedbu?method=get_anime').json()
    
    return json.loads(get_animes)

def get_animejanr(janr = ''):
    if janr != '':
        get_animejanrs =requests.get('https://dbuapi.herokuapp.com/aimedbu?method=get_animejanr&janr={}'.format(str(janr).lower())).json()
        
        return json.loads(get_animejanrs)
    else:
        return 'DBU_EROR: Укажите Жанр.'



# -*- coding: utf-8 -*-
from setuptools import setup

modules = \
['dbuanime']
setup_kwargs = {
    'name': 'dbuanime',
    'version': '0.0.1',
    'description': 'Поиск Аниме/Манги по: Жанру,Рандому,Топу по годам.',
    'long_description': None,
    'author': 'DarsoX',
    'author_email': 'darsox.anime@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'py_modules': modules,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
